<?php
class Section_Background_Rotator_Module extends ET_Builder_Module
{
	protected $module_credits = [
		'module_uri' => 'https://makeweb.com.au',
		'author' => 'MakeWeb',
		'author_uri' => 'https://makeweb.com.au',
	];
	
	public function init()
	{
		parent::init();
		$this->name             = 'Section Background Rotator';
		$this->version          = '1.0.7';
		$this->slug             = 'mw_section_background_rotator';
		$this->fb_support       = 'partial';
		$this->child_slug 		= 'mw_section_background_rotator_item';
		$this->main_css_element = '%%order_class%%';
	}

	public function get_settings_modal_toggles()
	{
		return [];
	}
	
	public function get_custom_css_fields_config()
	{
		$fields = [];
		return $fields;
	}
	
public function get_advanced_fields_config()
	{
		$advanced_fields = [];
		$advanced_fields["text"] = false;
		$advanced_fields["text_shadow"] = false;
		$advanced_fields['margin_padding'] = false;
		$advanced_fields['fonts'] = false;
		$advanced_fields['button'] = false;
	
		return $advanced_fields;
	}

	public function get_fields()
	{
		$fields = [];	
		
		$fields['duration'] = array(
			'label'           => esc_html__( 'Slide Duration', 'et_builder' ),
			'default'         => '4500',
			'range_settings'  => array(
				'min'  => '100',
				'max'  => '10000',
				'step' => '100',
			),
			'description'     => esc_html__( 'how long should each background show.', 'et_builder' ),
			'type'            => 'range',
		);
		
		$fields['transition_duration'] = array(
			'label'           => esc_html__( 'Transition Duration', 'et_builder' ),
			'default'         => '1000',
			'range_settings'  => array(
				'min'  => '100',
				'max'  => '5000',
				'step' => '100',
			),
			'description'     => esc_html__( 'how long should each background transition.', 'et_builder' ),
			'type'            => 'range',
		);
		
		$fields['randomise'] = array(
			'label'  => esc_html__( 'Randomise Images', 'et_builder' ),
			'type'  => 'yes_no_button',
			'option_category'  => 'basic_option',
			'options'          => array(
				'off' => et_builder_i18n( 'No' ),
				'on'  => et_builder_i18n( 'Yes' ),
			),
			'description'      => esc_html__( 'Load images in random order.', 'et_builder' ),
			'default_on_front' => 'off',
		);
		
		return $fields;
	}

	public function render($attrs, $content, $render_slug)
	{		
		$doc = new DOMDocument();
		$doc->loadHTML($this->content);
		
		// Initialize an array to store image URLs
		$imageUrls = array();
		
		// Find all elements with class 'et_pb_module_inner'
		$elements = $doc->getElementsByTagName('div');
		foreach ($elements as $element) {
			if ($element->getAttribute('class') == 'et_pb_module_inner') {
				// Extract image URL
				$imageUrl = trim($element->textContent);
				// Add the image URL to the array
				$imageUrls[] = $imageUrl;
			}
		}
		
		// Convert image URLs to comma-separated string
		$commaSeparatedUrls = implode(',', $imageUrls);
		$duration = $this->props['duration'];
		$transition_duration = $this->props['transition_duration'];
		$randomise = $this->props['randomise'];
		if($randomise == 'on'){
			$random = 'data-backstretchRand="true"';
		}else{
			$random ='';
		}
		
		$output = sprintf(
			'<div %2$s class="%3$s " 
				data-backstretch-images="%1$s" 
				data-duration="%4$s"
			    data-transitionDuration="%5$s"
				%6$s>
			</div>',
			$commaSeparatedUrls,
			$this->module_id(),
			$this->module_classname( $render_slug ),
			$duration,
			$transition_duration,
			$random
		);
		
		$current_directory_url = trailingslashit( wp_make_link_relative( get_template_directory_uri() . str_replace( get_template_directory(), '', __DIR__ ) ) );
		
		if (!is_admin()) {
			wp_enqueue_script('bg_rot', $current_directory_url.'bg_rot.js', ['jquery'], $this->version );
			// wp_enqueue_style('bg_rot', $current_directory_url.'bg_rot.css', [], $this->version );
		}
		
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => ".mw_section_background_rotator",
				'declaration' => 'margin: 0 !important;',
			)
		);

		return $output;
	}
}
new Section_Background_Rotator_Module;